
From: Dmitry Torokhov <dtor_core@ameritech.net>

===================================================================

ChangeSet@1.1793, 2004-06-17 18:18:43-05:00, dtor_core@ameritech.net
  Input: rename serio->driver to serio->port_data in preparation
         to sysfs integration
  
  Signed-off-by: Dmitry Torokhov <dtor@mail.ru>

===================================================================

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-sparc64-akpm/drivers/input/mouse/synaptics.c |    4 +-
 25-sparc64-akpm/drivers/input/serio/ambakmi.c   |   25 ++++++++--------
 25-sparc64-akpm/drivers/input/serio/gscps2.c    |    8 ++---
 25-sparc64-akpm/drivers/input/serio/i8042.c     |   14 ++++-----
 25-sparc64-akpm/drivers/input/serio/maceps2.c   |   36 ++++++++++++------------
 25-sparc64-akpm/drivers/input/serio/pcips2.c    |    8 ++---
 25-sparc64-akpm/drivers/input/serio/sa1111ps2.c |    8 ++---
 25-sparc64-akpm/drivers/input/serio/serport.c   |    6 ++--
 25-sparc64-akpm/include/linux/serio.h           |    2 -
 9 files changed, 56 insertions(+), 55 deletions(-)

diff -puN drivers/input/mouse/synaptics.c~input-serio-renames-1 drivers/input/mouse/synaptics.c
--- 25-sparc64/drivers/input/mouse/synaptics.c~input-serio-renames-1	2004-06-19 23:11:22.518267872 -0700
+++ 25-sparc64-akpm/drivers/input/mouse/synaptics.c	2004-06-19 23:11:22.533265592 -0700
@@ -214,7 +214,7 @@ static int synaptics_set_mode(struct psm
  ****************************************************************************/
 static int synaptics_pt_write(struct serio *port, unsigned char c)
 {
-	struct psmouse *parent = port->driver;
+	struct psmouse *parent = port->port_data;
 	char rate_param = SYN_PS_CLIENT_CMD; /* indicates that we want pass-through port */
 
 	if (psmouse_sliced_command(parent, c))
@@ -273,7 +273,7 @@ static void synaptics_pt_create(struct p
 	port->serio.name = "Synaptics pass-through";
 	port->serio.phys = "synaptics-pt/serio0";
 	port->serio.write = synaptics_pt_write;
-	port->serio.driver = psmouse;
+	port->serio.port_data = psmouse;
 
 	port->activate = synaptics_pt_activate;
 }
diff -puN drivers/input/serio/ambakmi.c~input-serio-renames-1 drivers/input/serio/ambakmi.c
--- 25-sparc64/drivers/input/serio/ambakmi.c~input-serio-renames-1	2004-06-19 23:11:22.519267720 -0700
+++ 25-sparc64-akpm/drivers/input/serio/ambakmi.c	2004-06-19 23:11:22.533265592 -0700
@@ -54,7 +54,7 @@ static irqreturn_t amba_kmi_int(int irq,
 
 static int amba_kmi_write(struct serio *io, unsigned char val)
 {
-	struct amba_kmi_port *kmi = io->driver;
+	struct amba_kmi_port *kmi = io->port_data;
 	unsigned int timeleft = 10000; /* timeout in 100ms */
 
 	while ((readb(KMISTAT) & KMISTAT_TXEMPTY) == 0 && timeleft--)
@@ -68,7 +68,7 @@ static int amba_kmi_write(struct serio *
 
 static int amba_kmi_open(struct serio *io)
 {
-	struct amba_kmi_port *kmi = io->driver;
+	struct amba_kmi_port *kmi = io->port_data;
 	unsigned int divisor;
 	int ret;
 
@@ -105,7 +105,7 @@ static int amba_kmi_open(struct serio *i
 
 static void amba_kmi_close(struct serio *io)
 {
-	struct amba_kmi_port *kmi = io->driver;
+	struct amba_kmi_port *kmi = io->port_data;
 
 	writeb(0, KMICR);
 
@@ -131,27 +131,28 @@ static int amba_kmi_probe(struct amba_de
 
 	memset(kmi, 0, sizeof(struct amba_kmi_port));
 
-	kmi->io.type	= SERIO_8042;
-	kmi->io.write	= amba_kmi_write;
-	kmi->io.open	= amba_kmi_open;
-	kmi->io.close	= amba_kmi_close;
-	kmi->io.name	= dev->dev.bus_id;
-	kmi->io.phys	= dev->dev.bus_id;
-	kmi->io.driver	= kmi;
+	kmi->io.type = SERIO_8042;
+	kmi->io.write = amba_kmi_write;
+	kmi->io.open = amba_kmi_open;
+	kmi->io.close = amba_kmi_close;
+	kmi->io.name = dev->dev.bus_id;
+	kmi->io.phys = dev->dev.bus_id;
+	kmi->io.port_data = kmi;
+
+	kmi->base = ioremap(dev->res.start, KMI_SIZE);
 
-	kmi->base	= ioremap(dev->res.start, KMI_SIZE);
 	if (!kmi->base) {
 		ret = -ENOMEM;
 		goto out;
 	}
 
+	kmi->irq = dev->irq[0];
 	kmi->clk = clk_get(&dev->dev, "KMIREFCLK");
 	if (IS_ERR(kmi->clk)) {
 		ret = PTR_ERR(kmi->clk);
 		goto unmap;
 	}
 
-	kmi->irq = dev->irq[0];
 	amba_set_drvdata(dev, kmi);
 
 	serio_register_port(&kmi->io);
diff -puN drivers/input/serio/gscps2.c~input-serio-renames-1 drivers/input/serio/gscps2.c
--- 25-sparc64/drivers/input/serio/gscps2.c~input-serio-renames-1	2004-06-19 23:11:22.520267568 -0700
+++ 25-sparc64-akpm/drivers/input/serio/gscps2.c	2004-06-19 23:11:22.534265440 -0700
@@ -288,7 +288,7 @@ static irqreturn_t gscps2_interrupt(int 
 
 static int gscps2_write(struct serio *port, unsigned char data)
 {
-	struct gscps2port *ps2port = port->driver;
+	struct gscps2port *ps2port = port->port_data;
 
 	if (!gscps2_writeb_output(ps2port, data)) {
 		printk(KERN_DEBUG PFX "sending byte %#x failed.\n", data);
@@ -304,7 +304,7 @@ static int gscps2_write(struct serio *po
 
 static int gscps2_open(struct serio *port)
 {
-	struct gscps2port *ps2port = port->driver;
+	struct gscps2port *ps2port = port->port_data;
 
 	gscps2_reset(ps2port);
 
@@ -319,7 +319,7 @@ static int gscps2_open(struct serio *por
 
 static void gscps2_close(struct serio *port)
 {
-	struct gscps2port *ps2port = port->driver;
+	struct gscps2port *ps2port = port->port_data;
 	gscps2_enable(ps2port, DISABLE);
 }
 
@@ -372,7 +372,7 @@ static int __init gscps2_probe(struct pa
 		(ps2port->id == GSC_ID_KEYBOARD) ? "keyboard" : "mouse" );
 
 	memcpy(&ps2port->port, &gscps2_serio_port, sizeof(gscps2_serio_port));
-	ps2port->port.driver = ps2port;
+	ps2port->port.port_data = ps2port;
 	ps2port->port.name = ps2port->name;
 	ps2port->port.phys = dev->dev.bus_id;
 
diff -puN drivers/input/serio/i8042.c~input-serio-renames-1 drivers/input/serio/i8042.c
--- 25-sparc64/drivers/input/serio/i8042.c~input-serio-renames-1	2004-06-19 23:11:22.522267264 -0700
+++ 25-sparc64-akpm/drivers/input/serio/i8042.c	2004-06-19 23:11:22.535265288 -0700
@@ -226,7 +226,7 @@ static int i8042_kbd_write(struct serio 
 
 static int i8042_aux_write(struct serio *port, unsigned char c)
 {
-	struct i8042_values *values = port->driver;
+	struct i8042_values *values = port->port_data;
 	int retval;
 
 /*
@@ -254,7 +254,7 @@ static int i8042_aux_write(struct serio 
 
 static int i8042_activate_port(struct serio *port)
 {
-	struct i8042_values *values = port->driver;
+	struct i8042_values *values = port->port_data;
 
 	i8042_flush();
 
@@ -282,7 +282,7 @@ static int i8042_activate_port(struct se
 
 static int i8042_open(struct serio *port)
 {
-	struct i8042_values *values = port->driver;
+	struct i8042_values *values = port->port_data;
 
 	if (values->mux != -1)
 		if (i8042_mux_open++)
@@ -321,7 +321,7 @@ irq_fail:
 
 static void i8042_close(struct serio *port)
 {
-	struct i8042_values *values = port->driver;
+	struct i8042_values *values = port->port_data;
 
 	if (values->mux != -1)
 		if (--i8042_mux_open)
@@ -356,7 +356,7 @@ static struct serio i8042_kbd_port =
 	.write =	i8042_kbd_write,
 	.open =		i8042_open,
 	.close =	i8042_close,
-	.driver =	&i8042_kbd_values,
+	.port_data =	&i8042_kbd_values,
 	.name =		"i8042 Kbd Port",
 	.phys =		I8042_KBD_PHYS_DESC,
 };
@@ -374,7 +374,7 @@ static struct serio i8042_aux_port =
 	.write =	i8042_aux_write,
 	.open =		i8042_open,
 	.close =	i8042_close,
-	.driver =	&i8042_aux_values,
+	.port_data =	&i8042_aux_values,
 	.name =		"i8042 Aux Port",
 	.phys =		I8042_AUX_PHYS_DESC,
 };
@@ -944,7 +944,7 @@ static void __init i8042_init_mux_values
 	sprintf(i8042_mux_short[index], "AUX%d", index);
 	port->name = i8042_mux_names[index];
 	port->phys = i8042_mux_phys[index];
-	port->driver = values;
+	port->port_data = values;
 	values->name = i8042_mux_short[index];
 	values->mux = index;
 }
diff -puN drivers/input/serio/maceps2.c~input-serio-renames-1 drivers/input/serio/maceps2.c
--- 25-sparc64/drivers/input/serio/maceps2.c~input-serio-renames-1	2004-06-19 23:11:22.524266960 -0700
+++ 25-sparc64-akpm/drivers/input/serio/maceps2.c	2004-06-19 23:11:22.536265136 -0700
@@ -54,7 +54,7 @@ struct maceps2_data {
 
 static int maceps2_write(struct serio *dev, unsigned char val)
 {
-	struct mace_ps2port *port = ((struct maceps2_data *)dev->driver)->port;
+	struct mace_ps2port *port = ((struct maceps2_data *)dev->port_data)->port;
 	unsigned int timeout = MACE_PS2_TIMEOUT;
 
 	do {
@@ -72,7 +72,7 @@ static irqreturn_t maceps2_interrupt(int
 				     struct pt_regs *regs)
 {
 	struct serio *dev = dev_id;
-	struct mace_ps2port *port = ((struct maceps2_data *)dev->driver)->port;
+	struct mace_ps2port *port = ((struct maceps2_data *)dev->port_data)->port;
 	unsigned int byte;
 
 	if (mace_read(port->status) & PS2_STATUS_RX_FULL) {
@@ -85,7 +85,7 @@ static irqreturn_t maceps2_interrupt(int
 
 static int maceps2_open(struct serio *dev)
 {
-	struct maceps2_data *data = (struct maceps2_data *)dev->driver;
+	struct maceps2_data *data = (struct maceps2_data *)dev->port_data;
 
 	if (request_irq(data->irq, maceps2_interrupt, 0, "PS/2 port", dev)) {
 		printk(KERN_ERR "Could not allocate PS/2 IRQ\n");
@@ -106,7 +106,7 @@ static int maceps2_open(struct serio *de
 
 static void maceps2_close(struct serio *dev)
 {
-	struct maceps2_data *data = (struct maceps2_data *)dev->driver;
+	struct maceps2_data *data = (struct maceps2_data *)dev->port_data;
 
 	mace_write(PS2_CONTROL_TX_CLOCK_DISABLE | PS2_CONTROL_RESET,
 		   data->port->control);
@@ -118,24 +118,24 @@ static struct maceps2_data port0_data, p
 
 static struct serio maceps2_port0 =
 {
-	.type	= SERIO_8042,
-	.open	= maceps2_open,
-	.close	= maceps2_close,
-	.write	= maceps2_write,
-	.name	= "MACE PS/2 port0",
-	.phys	= "mace/serio0",
-	.driver = &port0_data,
+	.type		= SERIO_8042,
+	.open		= maceps2_open,
+	.close		= maceps2_close,
+	.write		= maceps2_write,
+	.name		= "MACE PS/2 port0",
+	.phys		= "mace/serio0",
+	.port_data	= &port0_data,
 };
 
 static struct serio maceps2_port1 =
 {
-	.type	= SERIO_8042,
-	.open	= maceps2_open,
-	.close	= maceps2_close,
-	.write	= maceps2_write,
-	.name	= "MACE PS/2 port1",
-	.phys	= "mace/serio1",
-	.driver = &port1_data,
+	.type		= SERIO_8042,
+	.open		= maceps2_open,
+	.close		= maceps2_close,
+	.write		= maceps2_write,
+	.name		= "MACE PS/2 port1",
+	.phys		= "mace/serio1",
+	.port_data	= &port1_data,
 };
 
 static int __init maceps2_init(void)
diff -puN drivers/input/serio/pcips2.c~input-serio-renames-1 drivers/input/serio/pcips2.c
--- 25-sparc64/drivers/input/serio/pcips2.c~input-serio-renames-1	2004-06-19 23:11:22.525266808 -0700
+++ 25-sparc64-akpm/drivers/input/serio/pcips2.c	2004-06-19 23:11:22.536265136 -0700
@@ -45,7 +45,7 @@ struct pcips2_data {
 
 static int pcips2_write(struct serio *io, unsigned char val)
 {
-	struct pcips2_data *ps2if = io->driver;
+	struct pcips2_data *ps2if = io->port_data;
 	unsigned int stat;
 
 	do {
@@ -101,7 +101,7 @@ static void pcips2_flush_input(struct pc
 
 static int pcips2_open(struct serio *io)
 {
-	struct pcips2_data *ps2if = io->driver;
+	struct pcips2_data *ps2if = io->port_data;
 	int ret, val = 0;
 
 	outb(PS2_CTRL_ENABLE, ps2if->base);
@@ -119,7 +119,7 @@ static int pcips2_open(struct serio *io)
 
 static void pcips2_close(struct serio *io)
 {
-	struct pcips2_data *ps2if = io->driver;
+	struct pcips2_data *ps2if = io->port_data;
 
 	outb(0, ps2if->base);
 
@@ -155,7 +155,7 @@ static int __devinit pcips2_probe(struct
 	ps2if->io.close		= pcips2_close;
 	ps2if->io.name		= pci_name(dev);
 	ps2if->io.phys		= dev->dev.bus_id;
-	ps2if->io.driver	= ps2if;
+	ps2if->io.port_data	= ps2if;
 	ps2if->dev		= dev;
 	ps2if->base		= pci_resource_start(dev, 0);
 
diff -puN drivers/input/serio/sa1111ps2.c~input-serio-renames-1 drivers/input/serio/sa1111ps2.c
--- 25-sparc64/drivers/input/serio/sa1111ps2.c~input-serio-renames-1	2004-06-19 23:11:22.527266504 -0700
+++ 25-sparc64-akpm/drivers/input/serio/sa1111ps2.c	2004-06-19 23:11:22.537264984 -0700
@@ -95,7 +95,7 @@ static irqreturn_t ps2_txint(int irq, vo
  */
 static int ps2_write(struct serio *io, unsigned char val)
 {
-	struct ps2if *ps2if = io->driver;
+	struct ps2if *ps2if = io->port_data;
 	unsigned long flags;
 	unsigned int head;
 
@@ -122,7 +122,7 @@ static int ps2_write(struct serio *io, u
 
 static int ps2_open(struct serio *io)
 {
-	struct ps2if *ps2if = io->driver;
+	struct ps2if *ps2if = io->port_data;
 	int ret;
 
 	sa1111_enable_device(ps2if->dev);
@@ -154,7 +154,7 @@ static int ps2_open(struct serio *io)
 
 static void ps2_close(struct serio *io)
 {
-	struct ps2if *ps2if = io->driver;
+	struct ps2if *ps2if = io->port_data;
 
 	sa1111_writel(0, ps2if->base + SA1111_PS2CR);
 
@@ -247,7 +247,7 @@ static int ps2_probe(struct sa1111_dev *
 	ps2if->io.close		= ps2_close;
 	ps2if->io.name		= dev->dev.bus_id;
 	ps2if->io.phys		= dev->dev.bus_id;
-	ps2if->io.driver	= ps2if;
+	ps2if->io.port_data	= ps2if;
 	ps2if->dev		= dev;
 	sa1111_set_drvdata(dev, ps2if);
 
diff -puN drivers/input/serio/serport.c~input-serio-renames-1 drivers/input/serio/serport.c
--- 25-sparc64/drivers/input/serio/serport.c~input-serio-renames-1	2004-06-19 23:11:22.528266352 -0700
+++ 25-sparc64-akpm/drivers/input/serio/serport.c	2004-06-19 23:11:22.537264984 -0700
@@ -44,13 +44,13 @@ char serport_name[] = "Serial port";
 
 static int serport_serio_write(struct serio *serio, unsigned char data)
 {
-	struct serport *serport = serio->driver;
+	struct serport *serport = serio->port_data;
 	return -(serport->tty->driver->write(serport->tty, 0, &data, 1) != 1);
 }
 
 static void serport_serio_close(struct serio *serio)
 {
-	struct serport *serport = serio->driver;
+	struct serport *serport = serio->port_data;
 
 	serport->serio.type = 0;
 	wake_up_interruptible(&serport->wait);
@@ -83,7 +83,7 @@ static int serport_ldisc_open(struct tty
 	serport->serio.type = SERIO_RS232;
 	serport->serio.write = serport_serio_write;
 	serport->serio.close = serport_serio_close;
-	serport->serio.driver = serport;
+	serport->serio.port_data = serport;
 
 	init_waitqueue_head(&serport->wait);
 
diff -puN include/linux/serio.h~input-serio-renames-1 include/linux/serio.h
--- 25-sparc64/include/linux/serio.h~input-serio-renames-1	2004-06-19 23:11:22.529266200 -0700
+++ 25-sparc64-akpm/include/linux/serio.h	2004-06-19 23:11:22.538264832 -0700
@@ -21,7 +21,7 @@
 
 struct serio {
 	void *private;
-	void *driver;
+	void *port_data;
 	char *name;
 	char *phys;
 
_
